==> snpMatrix_1.12.0.zip: snpMatrix/doc/clustering-comparison-vignette.R <==
###################################################
### chunk number 1: init
###################################################
library(snpMatrix)
load(system.file("data/Genotypes.GenTrain1.Rda",package="snpMatrix"))
load(system.file("data/Genotypes.GenTrain2.Rda",package="snpMatrix"))


###################################################
### chunk number 2: 
###################################################
ab.signals <- read.wtccc.signals(system.file("data/example-new.txt", package="snpMatrix"),
                                 paste("rs", 1:99, sep=""))


###################################################
### chunk number 3: 
###################################################
col.summary(GenTrain2)[1:3,2:7]


###################################################
### chunk number 4: lothist
###################################################
result <- snp.compare(GenTrain1, GenTrain2)
diff.counts <- result$count
hist(diff.counts,breaks=50,col='black')


###################################################
### chunk number 5: 
###################################################
dim(GenTrain1)
diff.counts[diff.counts > 1550 * 0.1]
diff.counts[diff.counts > 1550 * 0.05]
worst.snps <- names(diff.counts[diff.counts > 1550 * 0.20])
worst.snps


###################################################
### chunk number 6: plot-clus1gtrs22
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs22']], GenTrain1[,'rs22'], title='rs22 GenTrain1')
snp.clust.plot(ab.signals[['rs22']], GenTrain2[,'rs22'], title='rs22 GenTrain2')


###################################################
### chunk number 7: plot-clus1gtrs27
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs27']], GenTrain1[,'rs27'], title='rs27 GenTrain1')
snp.clust.plot(ab.signals[['rs27']], GenTrain2[,'rs27'], title='rs27 GenTrain2')


###################################################
### chunk number 8: plot-clus1gtrs62
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs62']], GenTrain1[,'rs62'], title='rs62 GenTrain1')
snp.clust.plot(ab.signals[['rs62']], GenTrain2[,'rs62'], title='rs62 GenTrain2')


###################################################
### chunk number 9: plot-clus1gtrs80
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs80']], GenTrain1[,'rs80'], title='rs80 GenTrain1')
snp.clust.plot(ab.signals[['rs80']], GenTrain2[,'rs80'], title='rs80 GenTrain2')


###################################################
### chunk number 10: plot-clus1gtrs94
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs94']], GenTrain1[,'rs94'], title='rs94 GenTrain1')
snp.clust.plot(ab.signals[['rs94']], GenTrain2[,'rs94'], title='rs94 GenTrain2')


###################################################
### chunk number 11: lothist2
###################################################
count.signed <- result$count.signed
hist(count.signed,breaks=50,col='black')


###################################################
### chunk number 12: 
###################################################
result$count.signed[result$count.signed < -30]


###################################################
### chunk number 13: plot-clus1gtrs13
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs13']], GenTrain1[,'rs13'], title='rs13 GenTrain1')
snp.clust.plot(ab.signals[['rs13']], GenTrain2[,'rs13'], title='rs13 GenTrain2')


###################################################
### chunk number 14: plot-clus1gtrs69
###################################################
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs69']], GenTrain1[,'rs69'], title='rs69 GenTrain1')
snp.clust.plot(ab.signals[['rs69']], GenTrain2[,'rs69'], title='rs69 GenTrain2')


###################################################
### chunk number 15: 
###################################################
col.summary(GenTrain1)[worst.snps,2:7]
col.summary(GenTrain2)[worst.snps,2:7]

==> snpMatrix_1.14.6.zip: snpMatrix/doc/clustering-comparison-vignette.R <==
###################################################
### chunk number 1: init
###################################################
#line 58 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
library(snpMatrix)
load(system.file("data/Genotypes.GenTrain1.Rda",package="snpMatrix"))
load(system.file("data/Genotypes.GenTrain2.Rda",package="snpMatrix"))


###################################################
### chunk number 2: 
###################################################
#line 66 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
ab.signals <- read.wtccc.signals(system.file("data/example-new.txt", package="snpMatrix"),
                                 paste("rs", 1:99, sep=""))


###################################################
### chunk number 3: 
###################################################
#line 73 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
col.summary(GenTrain2)[1:3,2:7]


###################################################
### chunk number 4: lothist
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
result <- snp.compare(GenTrain1, GenTrain2)
diff.counts <- result$count
hist(diff.counts,breaks=50,col='black')


###################################################
### chunk number 5: 
###################################################
#line 94 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
dim(GenTrain1)
diff.counts[diff.counts > 1550 * 0.1]
diff.counts[diff.counts > 1550 * 0.05]
worst.snps <- names(diff.counts[diff.counts > 1550 * 0.20])
worst.snps


###################################################
### chunk number 6: plot-clus1gtrs22
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs22']], GenTrain1[,'rs22'], title='rs22 GenTrain1')
snp.clust.plot(ab.signals[['rs22']], GenTrain2[,'rs22'], title='rs22 GenTrain2')


###################################################
### chunk number 7: plot-clus1gtrs27
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs27']], GenTrain1[,'rs27'], title='rs27 GenTrain1')
snp.clust.plot(ab.signals[['rs27']], GenTrain2[,'rs27'], title='rs27 GenTrain2')


###################################################
### chunk number 8: plot-clus1gtrs62
###################################################
#line 133 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs62']], GenTrain1[,'rs62'], title='rs62 GenTrain1')
snp.clust.plot(ab.signals[['rs62']], GenTrain2[,'rs62'], title='rs62 GenTrain2')


###################################################
### chunk number 9: plot-clus1gtrs80
###################################################
#line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs80']], GenTrain1[,'rs80'], title='rs80 GenTrain1')
snp.clust.plot(ab.signals[['rs80']], GenTrain2[,'rs80'], title='rs80 GenTrain2')


###################################################
### chunk number 10: plot-clus1gtrs94
###################################################
#line 152 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs94']], GenTrain1[,'rs94'], title='rs94 GenTrain1')
snp.clust.plot(ab.signals[['rs94']], GenTrain2[,'rs94'], title='rs94 GenTrain2')


###################################################
### chunk number 11: lothist2
###################################################
#line 164 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
count.signed <- result$count.signed
hist(count.signed,breaks=50,col='black')


###################################################
### chunk number 12: 
###################################################
#line 171 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
result$count.signed[result$count.signed < -30]


###################################################
### chunk number 13: plot-clus1gtrs13
###################################################
#line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs13']], GenTrain1[,'rs13'], title='rs13 GenTrain1')
snp.clust.plot(ab.signals[['rs13']], GenTrain2[,'rs13'], title='rs13 GenTrain2')


###################################################
### chunk number 14: plot-clus1gtrs69
###################################################
#line 183 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
par(mfrow=c(1,2),plt=c(0.25, 0.9, 0.15, 0.8),col.main="black",col.axis="black",cex=0.5,cex.main=1.7)
snp.clust.plot(ab.signals[['rs69']], GenTrain1[,'rs69'], title='rs69 GenTrain1')
snp.clust.plot(ab.signals[['rs69']], GenTrain2[,'rs69'], title='rs69 GenTrain2')


###################################################
### chunk number 15: 
###################################################
#line 195 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpajagWM/R.INSTALL3ee753d/snpMatrix/inst/doc/clustering-comparison-vignette.Rnw"
col.summary(GenTrain1)[worst.snps,2:7]
col.summary(GenTrain2)[worst.snps,2:7]
